@@ -48,15 +48,11 @@ def init(name: str):
     try:
         os.mkdir(os.path.join(os.getcwd(), name))
     except FileExistsError:
-        click.echo(
-            f'Project or module with name "{name}" already exists. Exiting.'
-        )
+        click.echo(f'Project or module with name "{name}" already exists. Exiting.')
         exit(0)
 
     os.makedirs(os.path.join(os.getcwd(), name, "ext"))
-    ext_is_package = open(
-        os.path.join(os.getcwd(), name, "ext", "__init__.py"), "w"
-    )
+    ext_is_package = open(os.path.join(os.getcwd(), name, "ext", "__init__.py"), "w")
     ext_is_package.close()
     os.makedirs(os.path.join(os.getcwd(), name, "blueprints"))
     blueprint_is_package = open(
@@ -77,15 +73,12 @@ def init(name: str):
     templates_and_dest = {
         "app.pyt": os.path.join(os.getcwd(), name, "app.py"),
         "views.pyt": os.path.join(os.getcwd(), name, "views.py"),
-        "index.htmlt": os.path.join(
-            os.getcwd(), name, "templates", "index.html"
-        ),
-        "configuration.pyt": os.path.join(
-            os.getcwd(), name, "ext", "configuration.py"
-        ),
-        "settings.tomlt": os.path.join(
-            os.getcwd(), "instance", "settings.toml"
+        "index.htmlt": os.path.join(os.getcwd(), name, "templates", "index.html"),
+        "configuration.pyt": os.path.join(os.getcwd(), name, "ext", "configuration.py"),
+        ".secrets.settings.tomlt": os.path.join(
+            os.getcwd(), "instance", ".secrets.settings.toml"
         ),
+        "settings.tomlt": os.path.join(os.getcwd(), name, "settings.toml"),
         "manage.pyt": os.path.join(os.getcwd(), "manage.py"),
     }
 
@@ -112,6 +105,4 @@ def init(name: str):
 
 
 if __name__ == "__main__":
-    flaskstarter(
-        prog_name="flaskstarter"
-    )  # pylint: disable=unexpected-keyword-arg
+    flaskstarter(prog_name="flaskstarter")  # pylint: disable=unexpected-keyword-arg
